:mod:`zope.deferredimport`
==========================

Contents:

.. toctree::
   :maxdepth: 2

   narrative
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

